erin.cli package
================

Submodules
----------

erin.cli.scaffold module
------------------------

.. automodule:: erin.cli.scaffold
   :members:
   :undoc-members:
   :show-inheritance:

erin.cli.start module
---------------------

.. automodule:: erin.cli.start
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: erin.cli
   :members:
   :undoc-members:
   :show-inheritance:
